==> openshift-model-machineconfig-6.2.0-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ContainerRuntimeConfigurationFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContainerRuntimeConfigurationFluentImpl<A extends ContainerRuntimeConfigurationFluent<A>> extends BaseFluent<A> implements ContainerRuntimeConfigurationFluent<A>{
  public ContainerRuntimeConfigurationFluentImpl() {
  }
  public ContainerRuntimeConfigurationFluentImpl(ContainerRuntimeConfiguration instance) {
    this.withLogLevel(instance.getLogLevel()); 
    this.withLogSizeMax(instance.getLogSizeMax()); 
    this.withOverlaySize(instance.getOverlaySize()); 
    this.withPidsLimit(instance.getPidsLimit()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String logLevel;
  private Quantity logSizeMax;
  private Quantity overlaySize;
  private Long pidsLimit;
  private Map<String,Object> additionalProperties;
  public String getLogLevel() {
    return this.logLevel;
  }
  public A withLogLevel(String logLevel) {
    this.logLevel=logLevel; return (A) this;
  }
  public Boolean hasLogLevel() {
    return this.logLevel != null;
  }
  public Quantity getLogSizeMax() {
    return this.logSizeMax;
  }
  public A withLogSizeMax(Quantity logSizeMax) {
    this.logSizeMax=logSizeMax; return (A) this;
  }
  public Boolean hasLogSizeMax() {
    return this.logSizeMax != null;
  }
  public A withNewLogSizeMax(String amount,String format) {
    return (A)withLogSizeMax(new Quantity(amount, format));
  }
  public A withNewLogSizeMax(String amount) {
    return (A)withLogSizeMax(new Quantity(amount));
  }
  public Quantity getOverlaySize() {
    return this.overlaySize;
  }
  public A withOverlaySize(Quantity overlaySize) {
    this.overlaySize=overlaySize; return (A) this;
  }
  public Boolean hasOverlaySize() {
    return this.overlaySize != null;
  }
  public A withNewOverlaySize(String amount,String format) {
    return (A)withOverlaySize(new Quantity(amount, format));
  }
  public A withNewOverlaySize(String amount) {
    return (A)withOverlaySize(new Quantity(amount));
  }
  public Long getPidsLimit() {
    return this.pidsLimit;
  }
  public A withPidsLimit(Long pidsLimit) {
    this.pidsLimit=pidsLimit; return (A) this;
  }
  public Boolean hasPidsLimit() {
    return this.pidsLimit != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContainerRuntimeConfigurationFluentImpl that = (ContainerRuntimeConfigurationFluentImpl) o;
    if (logLevel != null ? !logLevel.equals(that.logLevel) :that.logLevel != null) return false;
    if (logSizeMax != null ? !logSizeMax.equals(that.logSizeMax) :that.logSizeMax != null) return false;
    if (overlaySize != null ? !overlaySize.equals(that.overlaySize) :that.overlaySize != null) return false;
    if (pidsLimit != null ? !pidsLimit.equals(that.pidsLimit) :that.pidsLimit != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(logLevel,  logSizeMax,  overlaySize,  pidsLimit,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (logLevel != null) { sb.append("logLevel:"); sb.append(logLevel + ","); }
    if (logSizeMax != null) { sb.append("logSizeMax:"); sb.append(logSizeMax + ","); }
    if (overlaySize != null) { sb.append("overlaySize:"); sb.append(overlaySize + ","); }
    if (pidsLimit != null) { sb.append("pidsLimit:"); sb.append(pidsLimit + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-machineconfig-6.7.2-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ContainerRuntimeConfigurationFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContainerRuntimeConfigurationFluentImpl<A extends ContainerRuntimeConfigurationFluent<A>> extends BaseFluent<A> implements ContainerRuntimeConfigurationFluent<A>{
  public ContainerRuntimeConfigurationFluentImpl() {
  }
  public ContainerRuntimeConfigurationFluentImpl(ContainerRuntimeConfiguration instance) {
    if (instance != null) {
      this.withLogLevel(instance.getLogLevel());
      this.withLogSizeMax(instance.getLogSizeMax());
      this.withOverlaySize(instance.getOverlaySize());
      this.withPidsLimit(instance.getPidsLimit());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String logLevel;
  private Quantity logSizeMax;
  private Quantity overlaySize;
  private Long pidsLimit;
  private Map<String,Object> additionalProperties;
  public String getLogLevel() {
    return this.logLevel;
  }
  public A withLogLevel(String logLevel) {
    this.logLevel=logLevel; return (A) this;
  }
  public Boolean hasLogLevel() {
    return this.logLevel != null;
  }
  public Quantity getLogSizeMax() {
    return this.logSizeMax;
  }
  public A withLogSizeMax(Quantity logSizeMax) {
    this.logSizeMax=logSizeMax; return (A) this;
  }
  public Boolean hasLogSizeMax() {
    return this.logSizeMax != null;
  }
  public A withNewLogSizeMax(String amount,String format) {
    return (A)withLogSizeMax(new Quantity(amount, format));
  }
  public A withNewLogSizeMax(String amount) {
    return (A)withLogSizeMax(new Quantity(amount));
  }
  public Quantity getOverlaySize() {
    return this.overlaySize;
  }
  public A withOverlaySize(Quantity overlaySize) {
    this.overlaySize=overlaySize; return (A) this;
  }
  public Boolean hasOverlaySize() {
    return this.overlaySize != null;
  }
  public A withNewOverlaySize(String amount,String format) {
    return (A)withOverlaySize(new Quantity(amount, format));
  }
  public A withNewOverlaySize(String amount) {
    return (A)withOverlaySize(new Quantity(amount));
  }
  public Long getPidsLimit() {
    return this.pidsLimit;
  }
  public A withPidsLimit(Long pidsLimit) {
    this.pidsLimit=pidsLimit; return (A) this;
  }
  public Boolean hasPidsLimit() {
    return this.pidsLimit != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerRuntimeConfigurationFluentImpl that = (ContainerRuntimeConfigurationFluentImpl) o;
    if (!java.util.Objects.equals(logLevel, that.logLevel)) return false;

    if (!java.util.Objects.equals(logSizeMax, that.logSizeMax)) return false;

    if (!java.util.Objects.equals(overlaySize, that.overlaySize)) return false;

    if (!java.util.Objects.equals(pidsLimit, that.pidsLimit)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(logLevel,  logSizeMax,  overlaySize,  pidsLimit,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (logLevel != null) { sb.append("logLevel:"); sb.append(logLevel + ","); }
    if (logSizeMax != null) { sb.append("logSizeMax:"); sb.append(logSizeMax + ","); }
    if (overlaySize != null) { sb.append("overlaySize:"); sb.append(overlaySize + ","); }
    if (pidsLimit != null) { sb.append("pidsLimit:"); sb.append(pidsLimit + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
